=========
pymhelper
=========

My <-> python  helper.

.. image:: https://img.shields.io/pypi/v/pymhelper.svg
        :target: https://pypi.python.org/pypi/pymhelper

.. image:: https://img.shields.io/travis/markeyev/pymhelper.svg
        :target: https://travis-ci.com/markeyev/pymhelper

* Free software: GNU General Public License v3
